@@ -120,7 +120,7 @@ class ImageSegmentation(CrowdsourcingTask):
     """
     This is a class for image segmentation tasks.
     """
-    def __init__(self, configuration, client):
+    def __init__(self, configuration, client, **kwargs):
         """
         This function initialises the ImageSegmentation class, which inherits attributes
         and methods from the superclass CrowdsourcingTask.
@@ -181,8 +181,9 @@ class ImageSegmentation(CrowdsourcingTask):
             # Set up the allowed shapes: note that their order will define the order in the UI
             shapes={'rectangle': True, 'polygon': True},
 
-            # Set minimum width in pixels
-            min_width=500,
+            # Set this element to use all available vertical space on the page. This should ensure
+            # that all UI elements are visible.
+            full_height=True,
 
             # Set up validation
             validation=tb.RequiredConditionV1(hint="Please select at least one area!"))
@@ -218,7 +219,7 @@ class AddOutlines(CrowdsourcingTask):
     """
     This is a class for tasks that add more bounding boxes to images with pre-existing labelled bounding boxes.
     """
-    def __init__(self, configuration, client):
+    def __init__(self, configuration, client, **kwargs):
         """
         This function initialises the AddOutlines class, which inherits attributes
         and methods from the superclass CrowdsourcingTask.
@@ -274,8 +275,12 @@ class AddOutlines(CrowdsourcingTask):
                       value, label in configuration["interface"]["labels"].items()]
 
         except KeyError:
-            msg.warn(f"Key 'labels' needs to be configured in the configuration of pool {configuration['name']} "
-                     f"under key 'interface'", exits=1)
+
+            msg.warn(f"Please add the key 'labels' under the top-level key 'interface' to define "
+                     f"the labels for bounding boxes. The labels should be provided as key/value "
+                     f"pairs, e.g. cat: Cat. The key must correspond to the label defined for "
+                     f"the bounding box in the input JSON, whereas the value is the text displayed "
+                     f"in the user interface.", exits=1)
 
         # Create the task interface; start by setting up the image segmentation interface
         img_ui = tb.ImageAnnotationFieldV1(
@@ -290,8 +295,9 @@ class AddOutlines(CrowdsourcingTask):
             # Set up the allowed shapes: note that their order will define the order in the UI
             shapes={'polygon': True, 'rectangle': True},
 
-            # Set minimum width in pixels
-            min_width=500,
+            # Set this element to use all available vertical space on the page. This should ensure
+            # that all UI elements are visible.
+            full_height=True,
 
             # Set up labels for the outlines
             labels=labels,
@@ -299,11 +305,16 @@ class AddOutlines(CrowdsourcingTask):
             disabled=False
         )
 
-        # Create a button for cases where a target does not exist
-        checkbox = tb.CheckboxFieldV1(
-            data=tb.OutputData(output_data['bool'], default=False),
-            label="Target does not exist"
-        )
+        # Create a checkbox for special cases
+        try:
+            checkbox = tb.CheckboxFieldV1(
+                data=tb.OutputData(output_data['bool'], default=False),
+                label=configuration['interface']['checkbox'])
+
+        except KeyError:
+            msg.warn(f"Please add the key 'checkbox' under the top-level key 'interface' to "
+                     f"define a text that is displayed above the checkbox. Define the text as a "
+                     f"string e.g. checkbox: There is nothing to outline.", exits=1)
 
         # Define the text prompt below the segmentation UI
         prompt = tb.TextViewV1(content=configuration['interface']['prompt'])
@@ -314,7 +325,7 @@ class AddOutlines(CrowdsourcingTask):
             validation=tb.AnyConditionV1(conditions=[tb.SchemaConditionV1(data=tb.OutputData(output_data['json']),
                                                                           schema={'type': 'array', 'minItems': 2}),
                                                      tb.EqualsConditionV1(data=tb.OutputData(output_data['bool']), to=True)],
-                                                     hint="Outline at least one target of specify if target does not exist."),
+                                                     hint="Outline at least one target or check the box if necessary."),
             )
         )
 
@@ -333,7 +344,7 @@ class SegmentationClassification(CrowdsourcingTask):
     """
     This is a class for binary segmentation classification tasks.
     """
-    def __init__(self, configuration, client):
+    def __init__(self, configuration, client, **kwargs):
         """
         This function initialises the SegmentationClassification class, which inherits attributes
         and methods from the superclass Task.
@@ -399,10 +410,12 @@ class SegmentationClassification(CrowdsourcingTask):
             # Set up the input data field
             image=tb.InputData(path=input_data['url']),
 
+            # Set labels
             labels=labels,
 
-            # Set minimum width in pixels
-            min_width=500,
+            # Set this element to use all available vertical space on the page. This should ensure
+            # that all UI elements are visible.
+            full_height=True,
 
             # Disable annotation interface
             disabled=True)
@@ -456,7 +469,7 @@ class LabelledSegmentationVerification(CrowdsourcingTask):
     """
     This is a class for binary segmentation verification tasks with labelled bounding boxes.
     """
-    def __init__(self, configuration, client):
+    def __init__(self, configuration, client, **kwargs):
         """
         This function initialises the LabelledSegmentationVerification class, which inherits attributes
         and methods from the superclass Task.
@@ -497,6 +510,7 @@ class LabelledSegmentationVerification(CrowdsourcingTask):
         Returns:
              A Toloka TaskSpec object.
         """
+
         # Define expected input and output types for the task
         expected_i, expected_o = {'url', 'json', 'bool'}, {'bool'}
 
@@ -514,8 +528,12 @@ class LabelledSegmentationVerification(CrowdsourcingTask):
                       value, label in configuration["interface"]["labels"].items()]
 
         except KeyError:
-            msg.warn(f"Key 'labels' needs to be configured in the configuration of pool "
-                     f"{configuration['name']} under key 'interface'", exits=1)
+
+            msg.warn(f"Please add the key 'labels' under the top-level key 'interface' to define "
+                     f"the labels for bounding boxes. The labels should be provided as key/value "
+                     f"pairs, e.g. cat: Cat. The key must correspond to the label defined for "
+                     f"the bounding box in the input JSON, whereas the value is the text displayed "
+                     f"in the user interface.", exits=1)
 
         # Create the task interface; start by setting up the image segmentation interface
         img_ui = tb.ImageAnnotationFieldV1(
@@ -527,8 +545,9 @@ class LabelledSegmentationVerification(CrowdsourcingTask):
             # Set up the input data field
             image=tb.InputData(path=input_data['url']),
 
-            # Set minimum width in pixels
-            min_width=500,
+            # Set this element to use all available vertical space on the page. This should ensure
+            # that all UI elements are visible.
+            full_height=True,
 
             # Set labels
             labels=labels,
@@ -539,12 +558,17 @@ class LabelledSegmentationVerification(CrowdsourcingTask):
         # Define the text prompt below the segmentation UI
         prompt = tb.TextViewV1(content=configuration['interface']['prompt'])
 
-        # Create a button for cases where a target does not exist
-        checkbox = tb.CheckboxFieldV1(
-            data=tb.OutputData('no_target', default=tb.InputData(input_data['bool'])),
-            label="Target does not exist",
-            disabled=True
-        )
+        # Create a checkbox for special cases
+        try:
+            checkbox = tb.CheckboxFieldV1(
+                data=tb.OutputData('no_target', default=tb.InputData(input_data['bool'])),
+                label=configuration['interface']['checkbox'],
+                disabled=True)
+
+        except KeyError:
+            msg.warn(f"Please add the key 'checkbox' under the top-level key 'interface' to "
+                     f"define a text that is displayed above the checkbox. Define the text as a "
+                     f"string e.g. checkbox: There is nothing to outline.", exits=1)
 
         # Set up a radio group for labels
         radio_group = tb.ButtonRadioGroupFieldV1(
@@ -586,14 +610,14 @@ class LabelledSegmentationVerification(CrowdsourcingTask):
 
         # Return the task specification
         return task_spec
-        
+
 
 class FixImageSegmentation(CrowdsourcingTask):
     """
     This is a class for fixing partially correct image segmentation tasks: modifying
     existing outlines and/or creating new ones.
     """
-    def __init__(self, configuration, client):
+    def __init__(self, configuration, client, **kwargs):
         """
         This function initialises the FixImageSegmentation class, which inherits attributes
         and methods from the superclass Task.
@@ -658,8 +682,9 @@ class FixImageSegmentation(CrowdsourcingTask):
             # Set up the allowed shapes: note that their order will define the order in the UI
             shapes={'rectangle': True, 'polygon': True},
 
-            # Set minimum width in pixels
-            min_width=500,
+            # Set this element to use all available vertical space on the page. This should ensure
+            # that all UI elements are visible.
+            full_height=True,
 
             # Set up validation
             validation=tb.RequiredConditionV1(hint="Please select at least one area!"),
@@ -690,7 +715,7 @@ class SegmentationVerification(CrowdsourcingTask):
     """
     This is a class for binary image segmentation verification tasks.
     """
-    def __init__(self, configuration, client):
+    def __init__(self, configuration, client, **kwargs):
         """
         This function initialises the SegmentationVerification class, which inherits attributes
         and methods from the superclass Task.
@@ -752,8 +777,9 @@ class SegmentationVerification(CrowdsourcingTask):
             # Set up the input data field
             image=tb.InputData(path=input_data['url']),
 
-            # Set minimum width in pixels
-            min_width=500,
+            # Set this element to use all available vertical space on the page. This should ensure
+            # that all UI elements are visible.
+            full_height=True,
 
             # Disable annotation interface
             disabled=True)
@@ -807,7 +833,7 @@ class MulticlassVerification(CrowdsourcingTask):
     """
     This is a class for multiclass image segmentation verification tasks.
     """
-    def __init__(self, configuration, client):
+    def __init__(self, configuration, client, **kwargs):
         """
         This function initialises the MulticlassVerification class, which inherits attributes
         and methods from the superclass Task.
@@ -869,8 +895,9 @@ class MulticlassVerification(CrowdsourcingTask):
             # Set up the input data field
             image=tb.InputData(path=input_data['url']),
 
-            # Set minimum width in pixels
-            min_width=500,
+            # Set this element to use all available vertical space on the page. This should ensure
+            # that all UI elements are visible.
+            full_height=True,
 
             # Disable annotation interface
             disabled=True)
@@ -926,7 +953,7 @@ class TextClassification(CrowdsourcingTask):
     This is a class for text classification tasks.
     """
 
-    def __init__(self, configuration, client):
+    def __init__(self, configuration, client, **kwargs):
         """
         This function initialises the TextClassification class, which inherits attributes
         and methods from the superclass CrowdsourcingTask.
@@ -1032,7 +1059,7 @@ class TextAnnotation(CrowdsourcingTask):
     This is a class for text annotation tasks.
     """
 
-    def __init__(self, configuration, client):
+    def __init__(self, configuration, client, **kwargs):
         """
         This function initialises the TextAnnotation class, which inherits attributes
         and methods from the superclass CrowdsourcingTask.
@@ -1130,3 +1157,140 @@ class TextAnnotation(CrowdsourcingTask):
 
         # Return the task specification
         return task_spec
+
+
+class LabelledSegmentationVerificationNoCheckbox(CrowdsourcingTask):
+    """
+    This is a class for binary segmentation verification tasks with labelled bounding boxes,
+    but the interface does not contain a checkbox that can be used e.g. to mark images with
+    nothing to outline.
+    """
+
+    def __init__(self, configuration, client):
+        """
+        This function initialises the LabelledSegmentationVerification class, which inherits attributes
+        and methods from the superclass Task.
+
+        Parameters:
+            configuration: A string object that defines a path to a YAML file with configuration.
+            client: A TolokaClient object with valid credentials.
+
+        Returns:
+            A LabelledSegmentationVerification object.
+        """
+        # Read the configuration from the YAML file
+        configuration = read_configuration(configuration=configuration)
+
+        # Specify task and task interface
+        task_spec = self.specify_task(configuration=configuration)
+
+        # Use the super() function to access the superclass Task and its methods and attributes.
+        # This will set up the project, pool and training as specified in the configuration file.
+        super().__init__(configuration, client, task_spec)
+
+    def __call__(self, input_obj):
+
+        # If the class is called, use the __call__() method from the superclass
+        super().__call__(input_obj, verify=True)
+
+        # When called, return the LabelledSegmentationVerification object
+        return self
+
+    @staticmethod
+    def specify_task(configuration):
+        """
+        This function specifies the task interface on Toloka.
+
+        Parameters:
+            configuration: A dictionary containing the configuration defined in the YAML file.
+
+        Returns:
+                A Toloka TaskSpec object.
+        """
+
+        # Define expected input and output types for the task
+        expected_i, expected_o = {'url', 'json'}, {'bool'}
+
+        # Configure Toloka data specifications and check the expected input against configuration
+        data_in, data_out, input_data, output_data = check_io(configuration=configuration,
+                                                              expected_input=expected_i,
+                                                              expected_output=expected_o)
+
+        # Add assignment ID to the input data
+        data_in['assignment_id'] = toloka.project.StringSpec(required=False)
+
+        try:
+            labels = [tb.ImageAnnotationFieldV1.Label(value=value, label=label) for
+                      value, label in configuration["interface"]["labels"].items()]
+
+        except KeyError:
+
+            msg.warn(f"Please add the key 'labels' under the top-level key 'interface' to define "
+                     f"the labels for bounding boxes. The labels should be provided as key/value "
+                     f"pairs, e.g. cat: Cat. The key must correspond to the label defined for "
+                     f"the bounding box in the input JSON, whereas the value is the text displayed "
+                     f"in the user interface.", exits=1)
+
+        # Create the task interface; start by setting up the image segmentation interface
+        img_ui = tb.ImageAnnotationFieldV1(
+
+            # Set up the output data field
+            data=tb.InternalData(path=input_data['json'],
+                                 default=tb.InputData(input_data['json'])),
+
+            # Set up the input data field
+            image=tb.InputData(path=input_data['url']),
+
+            # Set this element to use all available vertical space on the page. This should ensure
+            # that all UI elements are visible.
+            full_height=True,
+
+            # Set labels
+            labels=labels,
+
+            # Disable annotation interface
+            disabled=True)
+
+        # Define the text prompt below the segmentation UI
+        prompt = tb.TextViewV1(content=configuration['interface']['prompt'])
+
+        # Set up a radio group for labels
+        radio_group = tb.ButtonRadioGroupFieldV1(
+
+            # Set up the output data field
+            data=tb.OutputData(output_data['bool']),
+
+            # Create radio buttons
+            options=[
+                tb.fields.GroupFieldOption(value=True, label='Yes'),
+                tb.fields.GroupFieldOption(value=False, label='No')
+            ],
+
+            # Set up validation
+            validation=tb.RequiredConditionV1(hint="You must choose one response.")
+        )
+
+        # Add hotkey plugin
+        hotkey_plugin = tb.HotkeysPluginV1(key_1=tb.SetActionV1(data=tb.OutputData(output_data['bool']),
+                                                                payload=True),
+                                           key_2=tb.SetActionV1(data=tb.OutputData(output_data['bool']),
+                                                                payload=False))
+
+        # Set task width limit
+        task_width_plugin = tb.TolokaPluginV1(kind='scroll', task_width=500)
+
+        # Combine the task interface elements into a view
+        interface = toloka.project.TemplateBuilderViewSpec(
+            view=tb.ListViewV1([img_ui, prompt, radio_group]),
+            plugins=[hotkey_plugin, task_width_plugin]
+        )
+
+        # Create a task specification with interface and input/output data
+        task_spec = toloka.project.task_spec.TaskSpec(
+            input_spec=data_in,
+            output_spec=data_out,
+            view_spec=interface
+        )
+
+        # Return the task specification
+        return task_spec
